<?php

return [
    'ciext_parser_alias_callback' => [
        'rtform_open'       => 'rtform/parser/parser_rtform_open',
        'rtform_open_ajax'  => 'rtform/parser/parser_rtform_open_ajax',
        'form_close'        => 'rtform/parser/parser_form_close',
        'form_error'        => 'rtform/parser/parser_form_error',
        'form_set_value'    => 'rtform/parser/parser_form_set_value',
        'form_set_select'   => 'rtform/parser/parser_form_set_select',
        'form_set_checkbox' => 'rtform/parser/parser_form_set_checkbox',
        'form_set_radio'    => 'rtform/parser/parser_form_set_radio',
        'rtform_message'    => 'rtform/parser/parser_rtform_message',
        'rtform_row'        => 'rtform/parser/parser_rtform_row',
        'rtform_rows'       => 'rtform/parser/parser_rtform_rows',
    ],
];