<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

class Parser_rtform_open_ajax
{

    public function parse($form_code, $form_attributes = '', $multipart = false, $hash_time_point = 3)
    {
        $ci = get_instance();
        $ci->ciext->load_jquery();
        $ci->js_css->parse_js('rtform/ajax.js', ['id' => 'rtform_' . $form_code]);
        
        return $ci->load->library('rtform/parser/parser_rtform_open')->parse($form_code, $form_attributes, $multipart, $hash_time_point);
    }

}