<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

class Parser_form_set_select
{

    public function parse($field, $value = '', $default = false)
    {
        if (is_string($default)) {
            $default = strtolower($default) == 'true';
        }

        $ci = get_instance();
        $ci->load->helper('form');

        return set_select($field, $value, $default);
    }

}