<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

class Rtform_admin extends \Ciext\Controller\AbstractAdminController
{

    public function index()
    {
        $this->load->model('rtform/rtform_crud');

        return ['content' => $this->rtform_crud->render(), 'title' => $this->lang->line('Forms')];
    }

    public function request()
    {
        $this->load->model('rtform/rtform_request_crud');

        return ['content' => $this->rtform_request_crud->render(), 'title' => $this->lang->line('Requests')];
    }
}
