CREATE TABLE IF NOT EXISTS `rtform` ( 
`id_rtform` int(11) NOT NULL AUTO_INCREMENT,
`code` varchar(255) CHARACTER SET utf8 NOT NULL,
`alias` varchar(255) CHARACTER SET utf8 NOT NULL,
`recipients` text NOT NULL,
`recipients_template` int(11) NOT NULL,
`reply_template` int(11),
`success_message` text,
`form_class` varchar(255) CHARACTER SET utf8 NOT NULL,
PRIMARY KEY (`id_rtform`) 
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

CREATE TABLE IF NOT EXISTS `rtform_request` ( 
`id_rtform_request` int(11) NOT NULL AUTO_INCREMENT,
`id_rtform` int(11),
`date` DATETIME,
`data` text,
PRIMARY KEY (`id_rtform_request`) 
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;
