<?php

return [
    'developer_docs' => [
        'pages' => [
            'rtform_dev'   => [
                'label'    => 'RT Form',
                'file'     => __DIR__ . '/../docs/rtform.md',
                'position' => 70,
                'uri'      => 'rtform/index',
            ],
            'core_parsers' => [
                'pages' => [
                    'rtform_rtform_open'       => [
                        'label'    => 'Открывающийся тег формы (rtform_open)',
                        'file'     => __DIR__ . '/../docs/parsers/rtform_open.md',
                        'position' => 100,
                    ],
                    'rtform_rtform_open'       => [
                        'label'    => 'Открывающийся тег формы (rtform_open_ajax)',
                        'file'     => __DIR__ . '/../docs/parsers/rtform_open_ajax.md',
                        'position' => 100,
                    ],
                    'rtform_form_close'        => [
                        'label'    => 'Закрывающийся тег формы (form_close)',
                        'file'     => __DIR__ . '/../docs/parsers/same_as_ci.md',
                        'position' => 100,
                    ],
                    'rtform_form_error'        => [
                        'label'    => 'Ошибка поля формы (form_error)',
                        'file'     => __DIR__ . '/../docs/parsers/same_as_ci.md',
                        'position' => 100,
                    ],
                    'rtform_form_set_value'    => [
                        'label'    => 'Установка значение поля формы (form_set_value)',
                        'file'     => __DIR__ . '/../docs/parsers/same_as_ci.md',
                        'position' => 100,
                    ],
                    'rtform_form_set_select'   => [
                        'label'    => 'Установка значение тега select формы (form_set_select)',
                        'file'     => __DIR__ . '/../docs/parsers/same_as_ci.md',
                        'position' => 100,
                    ],
                    'rtform_form_set_checkbox' => [
                        'label'    => 'Установка значение тега checkbox формы (form_set_checkbox)',
                        'file'     => __DIR__ . '/../docs/parsers/same_as_ci.md',
                        'position' => 100,
                    ],
                    'rtform_form_set_radio'    => [
                        'label'    => 'Установка значение тега radio формы (form_set_radio)',
                        'file'     => __DIR__ . '/../docs/parsers/same_as_ci.md',
                        'position' => 100,
                    ],
                    'rtform_rtform_message'    => [
                        'label'    => 'Выввод сообщеня формы (rtform_message)',
                        'file'     => __DIR__ . '/../docs/rtform.md',
                        'position' => 100,
                    ],
                    'rtform_rtform_row'    => [
                        'label'    => 'Выввод элемента формы (rtform_row)',
                        'file'     => __DIR__ . '/../docs/parsers/rtform_row.md',
                        'position' => 100,
                    ],
                    'rtform_rtform_rows'    => [
                        'label'    => 'Выввод всех элементов формы (rtform_rows)',
                        'file'     => __DIR__ . '/../docs/parsers/rtform_rows.md',
                        'position' => 100,
                    ],
                ]
            ],
        ]
    ]
];
